diff --git a/spec/features/task_lists_spec.rb b/spec/features/task_lists_spec.rb
index 651792601ed9f6aa640b2f9d1531aeb85236e8d7..2099fc40ccabce2207a4f56ca902189ced976d97 100644
--- a/spec/features/task_lists_spec.rb
+++ b/spec/features/task_lists_spec.rb
@@ -69,7 +69,7 @@ feature 'Task Lists' do
 
     it 'provides a summary on Issues#index' do
       visit namespace_project_issues_path(project.namespace, project)
-      expect(page).to have_content("6 tasks (2 done, 4 unfinished)")
+      expect(page).to have_content("6 tasks (2 completed, 4 remaining)")
     end
   end
 
@@ -145,7 +145,7 @@ feature 'Task Lists' do
 
     it 'provides a summary on MergeRequests#index' do
       visit namespace_project_merge_requests_path(project.namespace, project)
-      expect(page).to have_content("6 tasks (2 done, 4 unfinished)")
+      expect(page).to have_content("6 tasks (2 completed, 4 remaining)")
     end
   end
 end
diff --git a/spec/support/taskable_shared_examples.rb b/spec/support/taskable_shared_examples.rb
index 77e0ed5f578e0ea94e78988029c734a570576aa2..927c72c74098f000ea1cd0be098009ba79da13f4 100644
--- a/spec/support/taskable_shared_examples.rb
+++ b/spec/support/taskable_shared_examples.rb
@@ -15,8 +15,8 @@ shared_examples 'a Taskable' do
 
   it 'returns the correct task status' do
     expect(subject.task_status).to match('5 tasks')
-    expect(subject.task_status).to match('2 done')
-    expect(subject.task_status).to match('3 unfinished')
+    expect(subject.task_status).to match('2 completed')
+    expect(subject.task_status).to match('3 remaining')
   end
 
   describe '#tasks?' do
diff --git a/app/models/concerns/taskable.rb b/app/models/concerns/taskable.rb
index 6e04578a7dfd2aa27db97d44526a4c2e3bb92b09..33b4814d7ec2d8f955cba8ba44bbc9bcfd818977 100644
--- a/app/models/concerns/taskable.rb
+++ b/app/models/concerns/taskable.rb
@@ -26,11 +26,11 @@ module Taskable
   end
 
   # Return a string that describes the current state of this Taskable's task
   # list items, e.g. "20 tasks (12 done, 8 unfinished)"
   def task_status
     return '' if description.blank?
 
     sum = tasks.summary
-    "#{sum.item_count} tasks (#{sum.complete_count} done, #{sum.incomplete_count} unfinished)"
+    "#{sum.item_count} tasks (#{sum.complete_count} completed, #{sum.incomplete_count} remaining)"
   end
 end
@@ -26,11 +26,11 @@ module Taskable
 
   # Return a string that describes the current state of this Taskable's task
-  # list items, e.g. "20 tasks (12 done, 8 unfinished)"
+  # list items, e.g. "20 tasks (12 completed, 8 remaining)"
   def task_status
     return '' if description.blank?